@@ -3,13 +3,13 @@
 kernelhat <- function(dpts, h, poly, win=apply(poly, 2, range),
                       delta=1, edge=TRUE)
 {
-    adapt <- chkerenl()
+    adapt <- chkernel()
     x <- seq(win[1,1]+delta/2, win[2,1], by=delta)
     y <- seq(win[1,2]+delta/2, win[2,2], by=delta)
     nx <- length(x)
     ny <- length(y)
     xygrids <- as.matrix(expand.grid(x=x, y=y))
-    ndx <- which(pnpoly(poly, xygrids) > 0)
+    ndx <- which(pinpoly(poly, xygrids) > 0)
     ## 0 outside, 1 boundary, 2 inside, -1 error
     pts <- xygrids[ndx,]
     npts <- nrow(pts)
